%define major           1
%define minor           52
%define archivever      %{major}%{minor}

%define section         free

Name:           bouncycastle
Version:        %{major}.%{minor}
Release:        2
Epoch:          0
Summary:        Bouncy Castle Crypto Package for Java
Group:          Development/Java
License:        BSD
URL:            http://www.bouncycastle.org/
Source0:        http://www.bouncycastle.org/download/crypto-%{archivever}.tar.gz
Requires:       jpackage-utils >= 0:1.5
BuildRequires:  ant
BuildRequires:  ant-junit
BuildRequires:	geronimo-javamail-1.4-api
BuildRequires:  junit
BuildRequires:  java-rpmbuild >= 0:1.5
BuildArch:      noarch
BuildRequires:  java-1.8.0-openjdk-devel
Obsoletes:      %{name}-provider < %{epoch}:%{version}-%{release}
Provides:       %{name}-provider = %{epoch}:%{version}-%{release}
Provides:       jce = 1.7.0.0

%description
The Bouncy Castle Crypto APIs consist of the following:
- A lightweight cryptography API in Java.
- A provider for the JCE and JCA.
- A clean room implementation of the JCE 1.2.1.
- Generators for Version 1 and Version 3 X.509 certificates and PKCS12 files.
- A signed jar version suitable for JDK 1.4 and the Sun JCE.

%package extras
Summary:	Extra packages of Bouncy Castle
Group:		Development/Java
Requires:	%{name}

%description extras
The SMIME/CMS, TSP, OpenPGP/BCPG portions of Bouncy Castle.

%package javadoc
Group:          Development/Java
Summary:        Javadocs for %{name}

%description javadoc
Javadocs for %{name}.

%prep
%setup -q -n crypto-%{archivever}
%{_bindir}/find . -name '*.jar' | %{_bindir}/xargs -t rm
perl -pi -e 's/<javac/<javac nowarn="true"/g' *.xml

%build
export CLASSPATH=$(build-classpath jaf javamail/mailapi junit)
export OPT_JAR_LIST="`cat %{_sysconfdir}/ant.d/junit`"
export JAVA_HOME=%{_jvmdir}/java-1.8.0
%ant -f ant/jdk15+.xml -Drelease.suffix=%{version} build-provider build build-test

%install

mkdir -p %{buildroot}%{_javadir}

pushd build/artifacts/jdk1.5/jars
for jar16 in {bcmail,bcpg,bcprov,bcprov-ext,bctest,bcpkix}-jdk15on-%{version}.jar; do
   jar16d=`echo $jar16 | %{__sed} s#-jdk15on##g`
   install -m 644 $jar16 %{buildroot}%{_javadir}/$jar16d
done
popd

pushd %{buildroot}%{_javadir}
  for jar in *-%{version}.jar; do
    %{__ln_s} $jar $(echo $jar | %{__sed} s#-%{version}##g)
  done
popd

mkdir -p %{buildroot}%{_javadocdir}/%{name}-%{version}
(cd %{buildroot}%{_javadocdir} && ln -s %{name}-%{version} %{name})

pushd build/artifacts/jdk1.5
  ver=16
  for javadoc in bcmail bcpg bcprov bcpkix; do
    mkdir -p %{buildroot}%{_javadocdir}/%{name}-%{version}/${javadoc}
    cp -a javadoc/${javadoc} %{buildroot}%{_javadocdir}/%{name}-%{version}/
  done
popd

mkdir -p %{buildroot}%{_javadir}/gcj-endorsed
(cd %{buildroot}%{_javadir}/gcj-endorsed && ln -s %{_javadir}/bcprov.jar .)

%post
if test -x %{_bindir}/rebuild-security-providers; then
  %{_bindir}/rebuild-security-providers
fi

%postun
if test -x %{_bindir}/rebuild-security-providers; then
  %{_bindir}/rebuild-security-providers
fi

%files
%defattr(0644,root,root,0755)
%doc *.html
# BEGIN PROVIDER
%{_javadir}/bcprov-%{version}.jar
%{_javadir}/bcprov.jar
%{_javadir}/bcprov-ext-%{version}.jar
%{_javadir}/bcprov-ext.jar
%{_javadir}/gcj-endorsed/bcprov.jar
# END PROVIDER

%files extras
%{_javadir}/bcmail-%{version}.jar
%{_javadir}/bcpg-%{version}.jar
%{_javadir}/bctest-%{version}.jar
%{_javadir}/bctest.jar
%{_javadir}/bcpkix-%{version}.jar
%{_javadir}/bcmail.jar
%{_javadir}/bcpg.jar
%{_javadir}/bcpkix.jar

%files javadoc
%defattr(0644,root,root,0755)
%doc %{_javadocdir}/%{name}-%{version}
%doc %{_javadocdir}/%{name}


%changelog

* Sat Mar 12 2016 Denis Silakov <dsilakov@gmail.com> 0:1.52-2
- (2365e22) Use geronimo-javamail-1.4-api


